@@ -3,7 +3,6 @@
 set -euf -o pipefail
 
 JAVA_VERSION=$1
-MAVEN_VERSION=$2
 
 printf "Installing, configuring, and initializing SDKMAN\n"
 curl -s "https://get.sdkman.io" | bash
@@ -12,7 +11,4 @@ set +uf
 source "${HOME}/.sdkman/bin/sdkman-init.sh"
 
 printf "Installing Azul Zulu JDKs via SDKMAN\n"
-sdk i java ${JAVA_VERSION}
-
-printf "Installing Apache Maven via SDKMAN\n"
-sdk i maven ${MAVEN_VERSION}
+sdk i java "${JAVA_VERSION}"
